<template>
	<b-modal
		:title="translations.productAddedToCart"
		id="mini-cart-modal"
		centered
		hide-footer
		no-close-on-backdrop
		ref="cartModal"
		size="lg"
		@hidden="toggleIsOpen()"
	>
		<div class="row">
			<div class="col">
				<b-alert
					v-html="alertContent()"
					class="custom-succes-alert"
					show
					variant="success"
				>
				</b-alert>
			</div>
		</div>
		<div class="row">
			<div class="col">
				<a class="btn ghost" @click="closeCart()">
					{{ translations.continueShopping }}
				</a>
			</div>
			<div class="col col-auto">
				<a class="btn btn-primary" @click="toCart()">
					{{ translations.goToCart }}
				</a>
			</div>
		</div>
		<div class="row mt-2" v-if="recommendedProducts?.length">
			<div class="col">
				<related-slider
					v-if="lastAddedProductName()"
					:item-list="{
						item_list_id: 'recommended-products',
						item_list_name: 'Recommended Products',
					}"
					:key="`${cartInfo?.recommendedProducts}-recommended-products`"
					:product_ids="recommendedProducts"
					:title="translations.maybeYoullLikeThis"
					ref="recommendedProducts"
				/>
			</div>
		</div>
	</b-modal>
</template>

<script>
	module.exports = {
		data() {
			return {
				cartAmount: undefined,
				cartUpdateUrl: "",
				changeAmountUrl: "",
				deleteItemUrl: "",
				firstLoad: true,
				items: [],
				jsBaseUrl,
				stockClass: "",
				stockText: "",
				total: "",
				totalProductsText: "",
			};
		},
		store,
		props: ["iconUrl", "cartUrl", "minimalDiscountPercentage", "translations"],
		components: {
			CartItem: `url:${jsBaseUrl}vue/ok_components/general/cart/CartItem.vue?v=${smsGeneralJsVersion}`,
			Loader: `url:${jsBaseUrl}vue/ok_components/general/Loader.vue?v=${smsGeneralJsVersion}`,
			RelatedSlider: `url:${jsBaseUrl}vue/ok_components/general/product-widget/RelatedSlider.vue?v=${smsGeneralJsVersion}`,
		},
		methods: {
			alertContent() {
				let content = this.lastAddedProductName() || this.translations.product;

				return `${content} ${this.translations.wasAddedToCart}`;
			},
			closeCart() {
				this.$refs["cartModal"].hide();
			},
			getProductVariant(attributes) {
				const { volume, color, skintype, spf } = attributes;
				const variantArr = [volume, color, skintype, spf];

				return variantArr.join(" ").trim();
			},
			lastAddedProductName() {
				return (
					this.lastAddedProduct?.nameFull ||
					this.dataLayer.find(item => item.event == "add_to_cart")?.ecommerce
						?.items[0]?.item_name ||
					null
				);
			},
			toCart() {
				if (!this.cartLoading) {
					window.location.href = this.cartUrl;
					this.$store.dispatch("changeCartLoadingState", true);
				}
			},
			toggleIsOpen() {
				this.$store.commit("togglePopState", "cart");
			},
		},
		mounted() {
			this.$store.dispatch("updateCartInfo");
		},
		computed: {
			cartContainsOutOfStockItems() {
				return this.items.some(item => item.stockClass !== "in-stock");
			},
			cartInfo() {
				return this.$store.getters.getCartInfo;
			},
			cartLoading() {
				return this.$store.getters.cartIsLoading;
			},
			cartUrls() {
				return {
					cartUpdateUrl: this.cartUpdateUrl,
					changeAmountUrl: this.changeAmountUrl,
					deleteItemUrl: this.deleteItemUrl,
				};
			},
			dataLayer() {
				return dataLayer;
			},
			dataLayerCartItems() {
				return this.items.map((item, index) => {
					return {
						item_id: item.id,
						item_name: item.fullName,
						discount: item.discount,
						index: index,
						item_brand: item.brand,
						item_category: item.categories[0],
						item_category2: item.categories[1] || "",
						item_category3: item.categories[2] || "",
						item_category4: item.categories[3] || "",
						item_category5: item.categories[4] || "",
						item_list_id: "pop_cart",
						item_list_name: "Pop Cart",
						item_variant: this.getProductVariant(item.attributes),
						price: Number(item.price),
						quantity: item.qty,
					};
				});
			},
			isOpen() {
				return this.$store.getters.getPopState("cart");
			},
			lastAddedProduct() {
				return this.$store.getters.getLastAddedProduct;
			},
			recommendedProducts() {
				return this.$store.getters.getRecommendedProducts;
			},
			unusedFreeGiftRules() {
				return this.$store.getters.unusedFreeGiftRules;
			},
		},
		watch: {
			cartInfo(newInfo, oldInfo) {
				if (newInfo !== oldInfo) {
					this.items = newInfo.items;
					this.cartAmount = newInfo.amount;
					this.totalProductsText = newInfo.totalProductsText;
					this.total = newInfo.total;
					this.stockClass = newInfo.stockClass;
					this.stockText = newInfo.stockText;
					this.cartUrl = newInfo.cartUrl;
					this.changeAmountUrl = newInfo.cartUpdateUrl;
					this.deleteItemUrl = newInfo.cartRemoveUrl;
				}
			},
			isOpen(isOpen) {
				if (isOpen) {
					this.$refs["cartModal"].show();
					dataLayer.push({ ecommerce: null }); // Clear the previous ecommerce object.
					dataLayer.push({
						event: "view_cart",
						ecommerce: {
							currency: currentCurrency,
							value: this.cartInfo.totalFlat,
							items: this.dataLayerCartItems,
						},
					});
				}
			},
			items(newValue, oldValue) {
				if (newValue !== oldValue) {
					this.firstLoad = false;
				}
			},
		},
	};
</script>

<style>
	* #pop-cart .custom-succes-alert {
		background: #f1f8f1;
		color: #2b2b2b;
		border: 1px solid #f1f8f1;
		border-left: 3px solid #badebb;
	}

	.text-none {
		text-transform: none !important;
	}

	#mini-cart-modal .swiper-slide {
		max-width: 200px;
	}
</style>
